ArgCommandLoading<DataT, ArgT extends Record> class

Inheritance
Implemented types
Available extensions

Constructors

ArgCommandLoading(ArgT arg)
const

Properties

arg → ArgT?

Available on ArgCommandState<T, ArgT>?, provided by the NullableArgCommandStateExtension extension

no setter
arg → ArgT
final
data → T?

Available on CommandState<T, ArgT>?, provided by the NullableCommandStateExtension extension

no setter
data → DataT?
no setterinherited
data → T?

Available on AsynchronousState<T, ArgT>, provided by the AsynchronousStateExtension extension

no setter
data → T?

Available on ArgCommandState<T, ArgT>?, provided by the NullableArgCommandStateExtension extension

no setter
data → T?

Available on CommandState<T, ArgT>, provided by the CommandStateExtension extension

no setter
error Object?
no setterinherited
error Object?

Available on ArgCommandState<T, ArgT>?, provided by the NullableArgCommandStateExtension extension

no setter
error Object?

Available on AsynchronousState<T, ArgT>, provided by the AsynchronousStateExtension extension

no setter
error Object?

Available on CommandState<T, ArgT>, provided by the CommandStateExtension extension

no setter
error Object?

Available on CommandState<T, ArgT>?, provided by the NullableCommandStateExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
isData bool

Available on AsynchronousState<T, ArgT>, provided by the AsynchronousStateExtension extension

no setter
isData bool
no setterinherited
isData bool

Available on CommandState<T, ArgT>, provided by the CommandStateExtension extension

no setter
isData bool

Available on CommandState<T, ArgT>?, provided by the NullableCommandStateExtension extension

no setter
isData bool

Available on ArgCommandState<T, ArgT>?, provided by the NullableArgCommandStateExtension extension

no setter
isDone bool

Available on CommandState<T, ArgT>?, provided by the NullableCommandStateExtension extension

no setter
isDone bool

Available on CommandState<T, ArgT>, provided by the CommandStateExtension extension

no setter
isDone bool
no setterinherited
isDone bool

Available on ArgCommandState<T, ArgT>?, provided by the NullableArgCommandStateExtension extension

no setter
isError bool

Available on AsynchronousState<T, ArgT>, provided by the AsynchronousStateExtension extension

no setter
isError bool
no setterinherited
isError bool

Available on CommandState<T, ArgT>, provided by the CommandStateExtension extension

no setter
isError bool

Available on CommandState<T, ArgT>?, provided by the NullableCommandStateExtension extension

no setter
isError bool

Available on ArgCommandState<T, ArgT>?, provided by the NullableArgCommandStateExtension extension

no setter
isInit bool

Available on CommandState<T, ArgT>, provided by the CommandStateExtension extension

no setter
isInit bool

Available on ArgCommandState<T, ArgT>?, provided by the NullableArgCommandStateExtension extension

no setter
isInit bool
no setterinherited
isInit bool

Available on CommandState<T, ArgT>?, provided by the NullableCommandStateExtension extension

no setter
isLoading bool

Available on AsynchronousState<T, ArgT>, provided by the AsynchronousStateExtension extension

no setter
isLoading bool

Available on ArgCommandState<T, ArgT>?, provided by the NullableArgCommandStateExtension extension

no setter
isLoading bool

Available on CommandState<T, ArgT>?, provided by the NullableCommandStateExtension extension

no setter
isLoading bool
no setterinherited
isLoading bool

Available on CommandState<T, ArgT>, provided by the CommandStateExtension extension

no setter
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

maybeWhen<R>({R init()?, R loading(ArgT arg)?, R data(ArgT arg, DataT data)?, R error(ArgT arg, Object error)?, required R orElse()}) → R
inherited
maybeWhen<R>({R init()?, R loading(ArgT? arg)?, R data(ArgT? arg, T data)?, R error(ArgT? arg, Object error)?, required R orElse()}) → R

Available on AsynchronousState<T, ArgT>, provided by the AsynchronousStateExtension extension

maybeWhen<R>({R init()?, R loading()?, R data(T data)?, R error(Object error)?, required R orElse()}) → R

Available on CommandState<T, ArgT>, provided by the CommandStateExtension extension

maybeWhen<R>({R init()?, R loading(ArgT arg)?, R data(ArgT arg, T data)?, R error(ArgT arg, Object error)?, required R orElse()}) → R

Available on ArgCommandState<T, ArgT>?, provided by the NullableArgCommandStateExtension extension

maybeWhen<R>({R init()?, R loading()?, R data(T data)?, R error(Object error)?, required R orElse()}) → R

Available on CommandState<T, ArgT>?, provided by the NullableCommandStateExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<R>({required R init(), required R loading(ArgT arg), required R data(ArgT arg, DataT data), required R error(ArgT arg, Object error)}) → R
inherited
when<R>({required R init(), required R loading(ArgT? arg), required R data(ArgT? arg, T data), required R error(ArgT? arg, Object error)}) → R

Available on AsynchronousState<T, ArgT>, provided by the AsynchronousStateExtension extension

when<R>({required R init(), required R loading(), required R data(T data), required R error(Object error)}) → R

Available on CommandState<T, ArgT>, provided by the CommandStateExtension extension

when<R>({required R init(), required R loading(ArgT arg), required R data(ArgT arg, T data), required R error(ArgT arg, Object error), required R orNull()}) → R

Available on ArgCommandState<T, ArgT>?, provided by the NullableArgCommandStateExtension extension

when<R>({required R init(), required R loading(), required R data(T data), required R error(Object error), required R orNull()}) → R

Available on CommandState<T, ArgT>?, provided by the NullableCommandStateExtension extension

whenOrNull<R>({R init()?, R loading(ArgT arg)?, R data(ArgT arg, DataT data)?, R error(ArgT arg, Object error)?}) → R?
inherited
whenOrNull<R>({R init()?, R loading(ArgT? arg)?, R data(ArgT? arg, T data)?, R error(ArgT? arg, Object error)?}) → R?

Available on AsynchronousState<T, ArgT>, provided by the AsynchronousStateExtension extension

whenOrNull<R>({R init()?, R loading()?, R data(T data)?, R error(Object error)?}) → R?

Available on CommandState<T, ArgT>, provided by the CommandStateExtension extension

whenOrNull<R>({R init()?, R loading(ArgT arg)?, R data(ArgT arg, T data)?, R error(ArgT arg, Object error)?}) → R?

Available on ArgCommandState<T, ArgT>?, provided by the NullableArgCommandStateExtension extension

whenOrNull<R>({R init()?, R loading()?, R data(T data)?, R error(Object error)?}) → R?

Available on CommandState<T, ArgT>?, provided by the NullableCommandStateExtension extension

where(bool match(ArgT? arg, DataT? data, Object? error)) ArgCommandState<DataT, ArgT>?
inherited
where(bool match(ArgT? arg, T? data, Object? error)) ArgCommandState<T, ArgT>?

Available on ArgCommandState<T, ArgT>?, provided by the NullableArgCommandStateExtension extension

whereArg(bool match(ArgT? arg)) ArgCommandState<DataT, ArgT>?
inherited
whereArg(bool match(ArgT? arg)) ArgCommandState<T, ArgT>?

Available on ArgCommandState<T, ArgT>?, provided by the NullableArgCommandStateExtension extension

whereData(bool match(DataT data)) ArgCommandState<DataT, ArgT>?
inherited
whereData(bool match(T? data)) ArgCommandState<T, ArgT>?

Available on ArgCommandState<T, ArgT>?, provided by the NullableArgCommandStateExtension extension

whereError(bool match(Object error)) ArgCommandState<DataT, ArgT>?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited