riverpod_craft
library
Classes
-
AnyNotifier<StateT, ValueT>
Notifiers
-
A base class for all "notifiers".
-
ArgCommandData<DataT, ArgT extends Record>
-
-
ArgCommandError<DataT, ArgT extends Record>
-
-
ArgCommandInit<DataT, ArgT extends Record>
-
-
ArgCommandLoading<DataT, ArgT extends Record>
-
-
ArgCommandState<T, ArgT extends Record>
-
-
AsyncData<ValueT>
Core
-
Creates an AsyncValue with a data.
-
AsyncError<ValueT>
Core
-
Creates an AsyncValue in the error state.
-
AsynchronousState<T, ArgT extends Record>
-
-
AsyncLoading<ValueT>
Core
-
Creates an AsyncValue in loading state.
-
AsyncNotifier<StateT>
Notifiers
-
A Notifier implementation that is asynchronously initialized.
-
AsyncNotifierProvider<NotifierT extends AsyncNotifier<ValueT>, ValueT>
Providers
-
A provider which creates and listen to an AsyncNotifier.
-
AsyncProviderFacade<T, ArgT extends Record>
-
-
AsyncProviderValue<T, ArgT extends Record, FacadeT extends AsyncProviderFacade<T, ArgT>>
-
-
AsyncResult<ValueT>
-
A variant of AsyncValue that excludes AsyncLoading.
-
AsyncValue<ValueT>
Core
-
A utility for safely manipulating asynchronous data.
-
CommandAnnotation
-
-
CommandData<T, ArgT extends Record>
-
-
CommandError<T, ArgT extends Record>
-
-
CommandInit<T, ArgT extends Record>
-
-
CommandLoading<T, ArgT extends Record>
-
-
CommandNotifier<DataT, Arg extends Record>
-
-
CommandProviderFacade<T, ArgT extends Record>
-
-
CommandProviderValue<T, ArgT extends Record>
-
-
CommandState<T, ArgT extends Record>
-
-
Consumer
Core
-
Build a widget tree while listening to providers.
-
ConsumerState<WidgetT extends ConsumerStatefulWidget>
Core
-
The State for a ConsumerStatefulWidget.
-
ConsumerStatefulWidget
Core
-
A StatefulWidget that has a State capable of reading providers.
-
ConsumerWidget
Core
-
The equivalent of a StatelessWidget that can listen to providers.
-
DataError<T>
-
-
DataLoading<T>
-
-
DataNotifier<T, Arg extends Record>
-
Unified data notifier that supports both Future and Stream data sources.
-
DataProviderFacade<T>
-
-
DataProviderValue<T, ArgT extends Record>
-
-
DataState<T>
-
-
DataSuccess<T>
-
-
Error<T>
-
-
FamilyAnnotation
-
-
FutureProvider<ValueT>
Providers
-
A provider that asynchronously creates a value.
-
KeepAliveAnnotation
-
-
KeepAliveManager
-
-
Notifier<ValueT>
Notifiers
-
A class which exposes a state that can change over time.
-
NotifierProvider<NotifierT extends Notifier<ValueT>, ValueT>
Providers
-
A provider that exposes a synchronous Notifier.
-
Ok<T>
-
-
Provider<ValueT>
Providers
-
A provider that exposes a read-only value.
-
ProviderAnnotation
-
-
ProviderContainer
Core
-
An object that stores the state of the providers and allows overriding the
behavior of a specific provider.
-
ProviderObserver
Core
-
An object that listens to the changes of a ProviderContainer.
-
ProviderObserverContext
Core
-
Information about the ProviderObserver event.
-
ProviderScope
Core
-
A widget that stores the state of providers.
-
ProviderSubscription<OutT>
Core
-
Represents the subscription to a
ProviderListenable.
-
ProviderValueAnnotation
-
-
Ref
Core
-
An object used by providers to interact with other providers and the life-cycles
of the application.
-
Result<T>
-
-
SelectedRefFacade<R>
-
A facade for selected provider state that supports chained select syntax:
ref.myProvider.select((s) => s.isLoading).watch()
-
SelectedWidgetRefFacade<R>
-
A facade for selected provider state for WidgetRef
-
StateDataNotifier<T, Arg extends Record>
-
-
StreamNotifier<ValueT>
Notifiers
-
A variant of AsyncNotifier which has build creating a Stream.
-
StreamNotifierProvider<NotifierT extends StreamNotifier<ValueT>, ValueT>
Providers
-
A provider which creates and listen to an StreamNotifier.
-
StreamProvider<ValueT>
Providers
-
Creates a stream and exposes its latest event.
-
UncontrolledProviderScope
Core
-
Expose a ProviderContainer to the widget tree.
-
WidgetRef
Core
-
An object that allows widgets to interact with providers.