CommandNotifier<DataT , Arg extends Record > class
abstract
Methods
action (Ref ref , Arg arg )
→ Future <DataT >
add (Arg arg )
→ void
build ()
→ ArgCommandState <DataT , Arg >
Initialize a Notifier .
override
listenSelf (void listener (ArgCommandState <DataT , Arg > ? previous , ArgCommandState <DataT , Arg > next ), {void onError (Object error , StackTrace stackTrace )? })
→ RemoveListener
Listens to changes on the value exposed by this provider.
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset ()
→ void
retry ()
→ void
runBuild ()
→ void
Executes Notifier.build .
inherited
toString ()
→ String
A string representation of this object.
inherited
updateShouldNotify (ArgCommandState <DataT , Arg > previous , ArgCommandState <DataT , Arg > next )
→ bool
A method invoked when the state exposed by this Notifier changes.
It compares the previous and new value, and return whether listeners
should be notified.
inherited